airwatch-sdk-fiori-plugin
===================

Use this document to install the VMware Workspace One  SDK Plugin for SAP Fiori applications. The plugin helps enterprise app developers add enterprise- grade security, conditional access, and compliance capabilities to mobile applications.

Plugin implements the X.509 certificate provider interface to the Kapsel logon plugin used by SAP Fiori applications.

Supported Components
--------------------

This plugin works with the listed component versions.

* Workspace ONE UEM Console 2107+ (may need to be higher depending on specific features)
* Android 5.0+ (for Android SDK component) / API level 21 OR above / Android Studio with the Gradle Android Build System (Gradle) 3.3.0 or later
* iOS 14.0+ (for iOS SDK component) / Xcode 14.0.1 or later

Installation
------------

To install the plugin from the command line, type `cordova plugin add airwatch-sdk-fiori-plugin` in the command line. This should be added before any other plugin is added to the app.
If using the SAP Web IDE to build a Kapsel/Fiori app, you can use the IDE to search for and install `airwatch-sdk-fiori-plugin`.

The AirWatch certificate provider will be registered in the Android and iOS native apps using the key `com.airwatch.x509provider`. To connect the Kapsel logon plugin to the AirWatch certificate provider, add the following value to your application's `appConfig.js` file:

         "certificate": "com.airwatch.x509provider",

**Note:** The download from NPM, usually takes 2-3 minutes on average, over high speed internet connection.

## Additional Setup
### iOS
Add following code in AppDelegate
```objective-c
-(BOOL)application:(UIApplication *)app openURL:(NSURL *)url options:(NSDictionary<UIApplicationOpenURLOptionsKey,id> *)options
{
  //Add following code for posting Notification for URL
  NSNotification *info = [[NSNotification alloc]initWithName:@"UIApplicationOpenURLOptionsSourceApplicationKey" object:url userInfo:options];
  [[NSNotificationCenter defaultCenter] postNotification:info];
  
  return YES;
}
```

Initialization
--------------

The plugin auto-starts on both Android and iOS devices and it automatically starts the Workspace One  SDK. After startup, the functions are available in the **window.plugins.airwatch** object. No other initialization is required to use the documented functions.

The Workspace One UEM console will automatically send to the device any certificates required by the application the first time the application is run, and the SDK on the device will store the certificate securely. Once a certificate has been sent to a device, it will not be sent again unless the application or its profile has been updated in the AirWatch console.

**Note :**  
Pre 2.0.0 version of the plugin certificate must be uploaded to Application profile (Credentials Payload) of Workspace One UEM Console and this Application profile needs to be assigned to the Fiori app along with the SDK profile.
Starting 2.0.0 version of the plugin, certificate needs to be uploaded via the Credentials payload of Custom SDK profile, the Fiori app needs to be assigned with this Custom SDK profile.

**Note :**  The certificate must to be uploaded via application profile in WSOne UEM console and that application profile needs to assigned to the generated app while uploading it to WSOne UEM console along with the SDK profile. 

To receive events from the SDK, an event listener must be initialized. See "Events" below.

Initialization of the SDK adds the listed features to your application, depending on the configurations set in the SDK profile in the Workspace One UEM Console.

* Application level passcode
* Application level tunneling of network traffic 
* Integrated authentication / single sign on 
* Data loss prevention
    * Disable Screenshot (Android only)
    * Restrict open-in for documents, web links, and email to approved applications only Restrict copy/paste (SDK provides flag value)
    * Restrict access to app when device is offline
* Branding of VMware AirWatch splash screens when SDK application is launched on device

Feature Implementation
-----------------------
Please follow document at [implementation](https://github.com/vmware-samples/workspace-ONE-SDK-integration-samples/blob/main/IntegrationGuideForCordova/GettingStarted.md).

### Quick Example

On deviceready, please set the SDK event listener: `window.plugins.airwatch.setSDKEventListener(sdkEventCallback)` . The sdkEventCallback is a function that takes two arguments:
1. A string that holds the name of the event fired.
2. An object that contains the additional info on the event function sdkEventCallback(event, info).

```
function sdkEventCallback(event, info)
{
    /* Check (event === "initSuccess") before using sdk functionalities */
}
```

Release Notes
--------------
* Latest versions of Workspace ONE SDKs (23.1.0 for iOS and 23.01 for Android).

Workspace One SDK Documentation
--------------------------
For further details about the Workspace One SDK, navigate to [Workspace-ONE-SDK](https://my.workspaceone.com/products/Workspace-ONE-SDK) and select the required platform, SDK version and Workspace ONE UEM console version.


License
---------
[VMWare License](https://vdc-download.vmware.com/vmwb-repository/dcr-public/c1dc8d44-8327-451d-9b95-1ecf1c0c03f2/b78c7651-b030-487d-93be-609117f5f935/License.pdf)


Open Source Link
--------------------------
[Open Source](https://www.vmware.com/content/dam/aw-microsites/open-source/assets/open_source_license_Airwatch_SDK_Cordova_Plugin_23.02_GA.txt)

Questions and Feedback
----------------------
For any questions/feedback or to report an issue, please reach out to [VMware support teams](https://secure.workspaceone.com/login)

